
import {  H4 } from "../components/Headings";

import { Section, Subesction } from "../components/sections";
import { useTabNavigation } from "../utils/TabNavigation";
import { H5 } from "../components/Headings";
import { useNavigation } from "../utils";
import { DownloadLink } from "../components/Buttons";
import { ThreeVertical, TwoHorizontal, TwoVertical } from "../components/Figures";
import { ResTable } from "../components/Table";
import { headercols, resultdata } from "../data/results-table";


export function Results() {
  useTabNavigation();
  const {goToPagesAndOpenTab} = useNavigation ();
  const {goToPageAndScroll} = useNavigation();

  return (
    <>
      <Section title="Abstract" id="Abstract">
         <p>For the prime editing of cystic fibrosis (CF), we on the one hand optimized a prime editing complex and on the other hand developed an efficient delivery system. For testing, we set up cell culture with model cell lines as well as primary cells taken from team members and a patient.</p>
<p>For editing, we first compared different existing prime editors (pCMV-PE2, pLV-PE_CO-Mini, pCMV-PE6c) and constructed a reporter plasmid simulating the CFTR context. In addition and to further enhance the editing process, we designed various pegRNAs tailored to our construct incorporating features such as silent edits, for a lower mismatch repair, and a 3′ stabilizing stem loop (tevropQ1). The aim was to identify the most effective pegRNA for our specific target, which is why pegRNA especially for CFTR F508del mutation were designed.</p> 

<p>As proof of concept, we transfected these constructs in HEK-293 and CFTR mutated CFB41o- cells and observed significant prime editing of our reporter via fluorescence microscopy. We identified the PE6c editor and our pegRNA variant 4 as optimal. This resulted in our Best New Basic Part, PEAR_CFTR. Furthermore, we extended our approach to primary human nasal epithelial cells generated from our own nasal epithelial cells through nasal swabs. By cultivating them in Air Liquid Culture (ALI) and Apical-Our Organoids, we successfully tested our technologies in vitro, mimicking the in vivo situation.</p> 

<p>Furthermore, we successfully designed and cloned novel nickases of Fanzor, which is special because of its smaller size and eukaryotic origin. This serves as valuable tool for future genome editing applications. </p>

<p>For delivery, lipid nanoparticles (LNPs) are a highly effective and versatile delivery system, valued for their larger cargo capacity, biocompatibility, and ability to protect RNA from degradation. To deliver our Prime Editing construct as mRNA, we optimized a Selective ORgan Targeting (SORT) LNP for targeted delivery to the lungs by using the cationic helper lipid DOTAP and encapsulating a stable Chitosan-RNA complex, achieving significant breakthroughs in transfection of in vitro lung epithelial cells. </p>

<p>We began by testing three different LNP formulations, starting with the Cayman LipidLaunc LNP-102 Exploration Kit. We confirmed by fluorescence microscopy, where Minicircle DNA effectively transfected HEK293 cells. Further experiments with the Corden LNP Stater Kit #2 failed to achieve successful transfection, likely due to increased cytotoxicity from a more cytotoxic PEG component. </p>

<p>Our successful formulation was a lung-specific SORT LNP, which demonstrated excellent stability, as confirmed by zeta potential measurements. Dynamic light scattering (DLS) analysis revealed an optimal particle size of 200 nm, aligning with literature and supporting the ability of the LNPs to penetrate deep lung regions via inhalation. Flow cytometry analysis showed that the SORT LNP had 14 times higher transfection efficiency compared to control formulations. Moreover, an MTT cytotoxicity assay revealed that the SORT LNP, along with Cayman LNPs, exhibited the lowest cytotoxicity, thanks to the use of low-molecular-weight PEG components. </p>

<p>To further enhance the stability and sustainability of the LNPs for inhalation, we incorporated chitosan-RNA complexes, which provide thermal stability and protect RNA from degradation by RNases. Integration of these complexes into the SORT LNP resulted in a lung-specific delivery platform. Using this system, we achieved highly efficient transfection of a bronchial cell line from a cystic fibrosis patient (CFBE41o- with F508del mutation), demonstrating the potential of this approach for targeted gene delivery to lung epithelial cells. These results highlight the remarkable efficiency, stability and specificity of our optimized SORT LNP formulation, positioning it as a promising platform for lung-specific genetic therapies. </p>
      </Section>
      <Section title="Experimental Design" id="ExpDes">
      <Subesction title="Proof of Concept" id="Results1">
          <H4 text="Proof-of-concept"/>
          <H5 text="Workflow"/>
          <p>The prepared pDAS12124-preedited plasmid serves as a positive control to validate the success of the experiment. A technical control with the pZMB938 plasmid confirms successful transfection of the cells. In the main part of the experiment, pDAS12489-2in1 and pCMV-PE2 are co-transfected. Successful transfection is visualised by GFP signals.</p> 
          <H5 text="Conclusion"/>
          <p>The microscopy data validates our proof of concept. Compared to our internal positive control, pDAS12124-preedited (see Figure 1), less cells co-transfected with pDAS12489 and pCMV-PE2 (see Figure 1) showed fluorescence. Contrary to our expectations, the technical transfection control with pZMB938 showed lower transfection efficiency. All negative controls showed no fluorescence.</p>
          <ThreeVertical
            description="Microscopy of HEK293 72h post transfection with lipofectamine 2000. Transfection with technical positive control pZMB938, internal positive control pDAS12124-preedited, co-transfection of pDAS12489 with pCMV-PE2, NTC, PE2 as control and pDAS12489 as control. All controls are negative and both positve controls as well as pDAS12489+pCMV-PE2 show fluorescence signals."
            num={1}
            pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild1-1.png"
            pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild1-2.png"
            pic3="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild1-3.png"
          />
          <H4 text="Transfection optimization"/>
          <H5 text="Workflow"/>
          <p>To optimise transfection efficiency, different dilutions and concentrations of DNA were used to find the best transfection conditions.</p> 
          <H5 text="Conclusion"/>
          <p>All 4 different transfection conditions were done with pZMB938 and showed good results, but best result were done when lipofectamine 2000 was diluted 1:10 and 1000 ng DNA was transfected.</p> 
          <TwoVertical
            description="Microscopy of HEK293 72h post transfection with lipofectamin 2000. Transfection with 1:10 or 1:25 diluted lipofectamine and 800 ng or 1000 ng of out technical positive control pZMB938."
            num={2}
            pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild2-1.png"
            pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild2-2.png"
          />
          <H5 text="Workflow"/>
          <p>Transfection with Lipofectamine 3000 was performed because of the probably better performance and transfection rate. The prepared pDAS12124-preedited plasmid serves as a positive control to validate the success of the experiment. A technical control with the pZMB938 plasmid confirmed successful transfection of the cells as before. In the main part of the experiment, pDAS12489-2in1 and pCMV-PE2 were co-transfected. Successful transfection and prime editing was detected by GFP signals.</p> 
          <H5 text="Conclusion"/>
          <p>Internal control and technical control showed higher transfection efficiency then in previous experiments, therefore transfection with lipofectamine 3000 seems to be more efficient than transfection with lipofectamine 2000. The fluorescence of pDAS12189+pCMV-PE2 was still quite low. All negative  controls are showed no fluorescence.</p>
          <ThreeVertical
          description="Microscopy of HEK293 72h post transfection with lipofectamine 2000. Transfection with technical positive control pZMB938, internal positive control pDAS12124-preedited, co-transfection of pDAS12489 with pCMV-PE2, NTC, PE2 as control and pDAS12489 as control. All controls are negative and both positve controls as well as pDAS12489+pCMV-PE2 show fluorescence signals."
          num={3}
          pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild3-1.png"
          pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild3-2.png"
          pic3="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild3-3.png"
          />
          <H5 text="Workflow"/>
          <p>Again a preliminary test with the technical positive control was conducted potentially optimize our transfection protocol and to train the handling.</p> 
          <H5 text="Conclusion"/>
          <p>The results of the test were not as good as expected. Nearly no transfection efficiency was visible. This could be due to too old HEK293 cells</p> 
          <TwoVertical
            description="Microscopy of HEK293 72h post transfection with lipofectaine 3000. Transfection of 500 ng or 1000 ng of our technical positive control pZMB938 with 1 µl or 1.5 µl of lipofectamine 3000."
            num={4}
            pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild4-1.png"
            pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild4-2.png"
          />
          <H5 text="Workflow"/>
          <p>HEK cells were thawed and another prelimary test was conducted. In this test two different transfection agents were used (Lipofectamine 3000 & CaCl2) to check which one is better suited for our experiments. The literature uses lipofectamine 3000 but CaCl2 transfection is much cheaper.</p> 
          <H5 text="Conclusion"/>
          <p>Both transfections are working out well but the efficiency of the lipofectamine transfection was much higher.</p>
          <div className="figure-wrapper">
              <figure>
                    <img src="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild5.png" style={{height: "10%", width: "auto"}}/>
                    <figcaption> <b>Figure 5.</b>Microscopy of HEK293 72h post transfection with lipofectamine 3000 with 1000 ng or 1500 ng technical positive control pZMB938. Both transfections show fluorescence signals.</figcaption>
              </figure>
          </div>          
          <TwoVertical
            description="Microscopy of HEK293 72h post transfection with CaCl2 with 500 ng, 1000 ng or 1500 ng pZMB938. All transfections show fluorescence signals."
            num={6}
            pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild6-1.png"
            pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild6-2.png"
          />
          <H5 text="Workflow"/>
          <p>One last time the transfection of pDAS12189+pCMV-PE2 was conducted. Although our proof-of-concept already showed successful editing the first time, we repeated the experiment to get better transfection efficiency.</p> 
          <H5 text="Conclusion"/>
          <p>The transfection efficiency was much better. Our proof-of-concept was working correctly. The reporter system pDAS12189 only led to production of a fluorescent signal when co transfected with a prime editing complex as pCMV-PE2.</p> 
          <TwoVertical
            description="Microscopy of HEK293 72h post transfection with lipofectamine 2000. Transfection with technical positive control pZMB938, internal positive control pDAS12124-preedited, co-transfection of pDAS12489 with pCMV-PE2, NTC, PE2 as control and pDAS12489 as control. All controls are negative and both positve controls as well as pDAS12489+pCMV-PE2 show fluorescence signals."
            num={7}
            pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild7-1.png"
            pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild7-2.png"
          />
      </Subesction>
      <Subesction title="Mechanism" id="Results2">
          <H4 text="Initial testing of pegRNAs and Evaluation of silent edits"/>
          <H5 text="Workflow"/>
          <p>With this experiment we wanted to compare the efficiency of pegRNAs with and without silent edits.</p> 
          <H5 text="Conclusion"/>
          <p>The Flow Cytometry analysis shows that pegRNA without silent edits (pegRNA1) had a 2.05 times higher transfection efficiency than pegRNA with silent edits (pegRNA2).</p>         
          <TwoHorizontal 
            description="Flow cytometry analysis of pegRNAs with and without silent edits. Histograms of cell count applied against fluorescence intensity of healthy HEK293 cells (left) with untransfected cells as negative control, pDAS12124 pre-edited as internal positive control and pegRNAs with (pegRNA1) and without (pegRNA2) silent edits 72 h after transfection. The portion of fluorescent cells is normalized to the internal positive control (right)."
            num={8}
            pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/se-nose.png"
            pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild8.png"
          />
          <H4 text="Screening of pegRNA variants"/>
          <H5 text="Workflow"/>
          <p>Cotransfection of pPEAR_CFTR and PE2 and also 1 of the 14 pegRNAs to compare the transfection efficiency of all of our designed pegRNAs.</p> 
          <H5 text="Conclusion"/>
          <p>The pegRNAs lead to differing amounts of cells showing fluorescence, which, assuming comparable transfection efficiencies, indicates varying prime editing efficiency. The pegRNA7 showed the highest transfection efficiency (see Figure 9).</p>
          <ResTable cols={headercols} data={resultdata}/>
          <div className="figure-wrapper">
              <figure>
                    <img src="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild9.png" style={{height: "10%", width: "auto"}}/>
                    <figcaption> <b>Figure 9.</b>Percentage of fluorescent HEK293 cells 72 h after transfection with various pegRNAs (pegRNA1-14) normalized to pDAS12124 pre-edited as internal positive control as result of flow cytometry analysis.</figcaption>
              </figure>
          </div>
          <H4 text="Application lung epithelial cell lines"/>
          <H5 text="Workflow"/>
          <p>We tried to transfect CFBE41o- cells with pDAS12124-preedited, our internal positive control, to check if a transfection of this cell line is possible. Furthermore we tried to co transfect the CFBE41o- with pPEAR_CFTR, PE6c and pegRNA4.</p> 
          <H5 text="Conclusion"/>
          <p>Transfection of CFBE41o- with pDAS12124-preedited was successful (see Figure 10). After 24 hours a successful co transfection of pPEAR_CFTR with PE6c and pegRNA4 was visible, although the transfection efficiency was really bad (see Figure 10).</p>
          <TwoVertical
           description="Microscopy results after 24h or 48h. Transfection of pDAS12124-preedited with lipofectamine 3000 was successfully done in CFBE41o- cell line and visible after 48h. CFBE41o- cell line was transfected with pDAS-IDT with Lipofectamine 3000 and afterwards with LNPs including PE6c and pegRNA4 and was after 24h fluorescence visible."
           num={10}
           pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild10-1.png"
           pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild10-2.png"
           />
          <p>Moreover transfection was conducted in human nasal epithelial cells (hNECs) in Air-liquid interface cultures as well as apical-out airway organoids (see Figure 11). No fluorescence was visible. </p>
          <TwoVertical
           description="Microscopy of HEK 72h post transfection with lipofectamine 3000. Co-transfection of pPEAR_CFTR with PE6c and pegRNA4. Both show no fluorescence signals."
           num={11}
           pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/ali-tr.png"
           pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/aoao-tr.png"
           />
          <H4 text="Comparison of prime editing complexes PE2 and PE_CO-Mini"/>
          <H5 text="Workflow"/>
          <p>pCMV-PE2 was co transfected with pDAS12489 and pCMV-PE_CO-Mini was co transfected with pDAS12489 in HEK293 cell line.</p> 
          <H5 text="Conclusion"/>
          <p>The Flow Cytometry results show that transfection with pCMV-PE2 as the prime editing complex had editing efficiency of 52.90% when normalized on pDAS12124-preedited. When pCMV-PE_CO-Mini was used as a prime editing complex it had a transfection efficiency of 2.54% (see Figure 12, 13).</p>
          <TwoVertical
           description="Microscopy of HEK 72h post transfection with lipofectamine 3000. Co-transfection of pDAS12489 with pCMV-PE2 or pDAS12489 with LV-PE_CO-Mini. Both show fluorescence signals."
           num={12}
           pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild11-1.png"
           pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild11-2.png"
           />
           <div className="figure-wrapper">
              <figure>
                    <img src=" Flow Cytometry analysis to compare prime editing complexes PE2 and PE_CO-Mini. Histograms of cell count applied against fluorescence intensity of healthy HEK293 cells (left) with untransfected cells as negative control, pDAS12124 pre-edited as internal positive control 72 h after transfection." style={{height: "10%", width: "auto"}}/>
                    <figcaption> <b>Figure 13. </b>Flow Cytometry analysis to compare prime editing complexes PE2 and PE_CO-Mini</figcaption>
              </figure>
          </div>
          <H5 text="Workflow"/>
          <p>We compared the 3 different Prime Editing complexes (pCMV-PE2, pCMV-PE2_CO-Mini & pCMV-PE6c) to check which one has the best transfection efficiency.</p> 
          <H5 text="Conclusion"/>
          <p>The Flow Cytometry measurement shows the fluorescence rate cells co-transfected with pDAS12489 and pCMV-PE6c as a prime editing complex. The editing efficiency off PE6c was by far the highest (81.88%) (see Figure 14, 15). The efficiency was 1.55 higher than the efficiency when pCMV-PE2 was used as prime editing complex (see Figure 13).</p>
          <div className="figure-wrapper">
              <figure>
                    <img src="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild13.png" style={{height: "10%", width: "auto"}}/>
                    <figcaption> <b>Figure 14. </b>Microscopy of HEK293 72h post transfection with lipofectamine 3000 and co transfection with pCMV-PE6c and pDAS12489.</figcaption>
              </figure>
          </div>
          <TwoHorizontal
          description="Flow cytometry analysis for evaluation of performance of prime editor variants. Histograms of cell count applied against fluorescence intensity of healthy HEK293 cells (left) with untransfected cells as negative control, pDAS12124 pre-edited as internal positive control and PE6c, PE2 and PE2C 72 h after transfection. The portion of fluorescent cells is normalized to the internal positive control (right)."
          num={15}
          pic1="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/pe2-pe-co-pe6c.png"
          pic2="https://static.igem.wiki/teams/5247/photos/facs-results-mechanism/bild12.png"
          /> 
      </Subesction >
      <Subesction  title="Delivery" id="Results3">
      <H4 text="RNA Synthesis"/>
      <div className="row align-items-center">
        <div className="col">
          <figure>
            <img src="https://static.igem.wiki/teams/5247/delivery/results/rna-gel-final.png"/>
            <figcaption>
              <b>Figure 1. </b>
              Gel of Denaturing RNA Gel Electrophoresis for mRNA synthesized from pcDNA 3.1 eYFP indicating successful RNA synthesis. Lane 1: Low Range Ribo Ruler, Lane 2: FLuc Control Template, Lane 3: Negative Control, Lane 4-9 mRNA from pcDNA 3.1 eYFP.
            </figcaption>
          </figure>
        </div>
        <div className="col">
          <p>We began by synthesizing mRNA <i>in vitro</i> using a plasmid with a eYFP reporter from Addgene (pcDNA 3.1 eYFP) before proceeding with the synthesis of our approximately 6000 bp prime editing RNA. This was done to test the transfection efficiency and compatibility of our lipid nanoparticles (LNPs). The synthesis was successful, yielding an average of 1400 ng/µl of purified mRNA from 1 µg of plasmid DNA determined by Nanodrop measurement (data not shown). The size and integrity of the synthesized RNA were confirmed using a denaturing RNA gel, where we expected to see a product of 900 nucleotides. As anticipated, a strong and prominent band corresponding to this size was observed (Figure X). This mRNA was subsequently used in further LNP formulations with RNA.</p>
        </div>
      </div>
      <H4 text="Cayman LNP"/>
            <div className="row align-items-center">
            <div className="col">
            <p>Next, we formulated the LNPs using the Cayman LipidLaunch™ LNP-102 Exploration Kit after the manufacturers protocol. The initial assembly attempt was unsuccessful, as no cloudy, bluish solution formed after mixing the lipids. Additionally, transfection of HEK293 cells with LNPs containing nucleic acids did not produce any fluorescence. After consulting with expert <a onClick={() => goToPagesAndOpenTab('radukic', '/human-practices')}>Dr. Marco Radukic</a> and adjusting our LNP formulation and transfection protocols, specifically by pre-acidifying the OptiMEM medium, we were able to successfully assemble and transfect the LNPs. We also got from him Minicircle DNA from <a href="https://www.plasmidfactory.com/custom-dna/minicircle-dna/" title="PlasmidFactory" >PlasmidFactory</a> as a small plasmid carrying an eYFP gene and easy to transform, by that serving as a positive control in our experiments. Upon pipetting the components together, the solution immediately turned cloudy and bluish, indicating successful LNP formation (Figure X).</p>
            </div>
            <div className="col">
              <figure>
                <img src="https://static.igem.wiki/teams/5247/delivery/results/caymanlnpblue.webp"/>
                <figcaption>
                <b>Figure X. </b>
                  Cayman LNP Formation indicated by blue color and turbidity. Mini DNA = Minicircle DNA from PlasmidFactory.
                  </figcaption>
              </figure>
            </div>
          </div>
          <H5 text="Transfection"/>
            <p>To evaluate the efficiency of transfection, we performed fluorescence microscopy (Leica DMI6000 B at 20x magnification) on HEK293 cells transfected with LNP-formulated DNA and mRNA of pcDNA 3.1 eYFP, Minicircle DNA as technical positive control and LNP without cargo.</p>
            <p>24 h, 48 h and 72 h post-transfection, we observed in the conditions with Lipofectamine alone, or combined with DNA or RNA, no fluorescence, indicating unsuccessful transfection. Similarly, no fluorescence was seen in cells treated with LNPs alone or in combination with DNA or RNA. When LNPs were combined with Minicircle DNA, clear fluorescence was observed, indicating successful transfection and expression of our eYFP reporter under this condition (figure X). However, a strong background fluorescence from the OptiMEM medium was observed, complicating the analysis.</p>
            <p>Overall, among all the tested conditions, the LNP formulation with Minicircle DNA was the only combination that resulted in noticeable fluorescence, suggesting it to be the most effective transfection method for HEK293 cells in this experiment.</p>
            <figure>
              <img src="https://static.igem.wiki/teams/5247/delivery/results/precyse/cayman.png"/>
              <figcaption>
                <b>Figure 18. </b>
                Overlay of phase contrast and fluorescence microscopic images of transfected HEK293 cells at 20x magnification after 72 h post-transfection with different Cayman LNP formulations recorded with Leica DMI6000 B. For Lipofectamine (Lipo) + Minicircle DNA (Mini DNA) only the fluorescence image is shown.
              </figcaption>
            </figure>
          <H5 text="SEM"/>
          <div className="row align-items-center">
            <div className="col">
              <p>Scanning Electron Microscopy (SEM) (Phenom ProX, Thermo Fisher) was employed by us to examine the morphology and surface characteristics of Cayman LNPs. The SEM images revealed that the LNPs displayed a generally spherical morphology with a relatively smooth surface (Figure X). The average particle size was approximately 200 nm. However, a heterogeneous distribution of particle sizes was observed, with some larger, round structures present. These larger structures could potentially indicate aggregated LNPs.</p>
            </div>
            <div className="col">
              <figure>
                <img src="https://static.igem.wiki/teams/5247/delivery/results/screenshot-2024-10-01-200629.png" alt="CayREM" style={{maxHeight: "200pt"}}/> 
                <figcaption>
                  <b>Figure X.</b>
                  SEM image of Cayman LNPs (10,000x magnification) with Topography mode.                </figcaption>
              </figure>
            </div>
          </div>
          <p>While many particles retained their structural integrity, the presence of these aggregates suggests that, under certain conditions, the LNPs may tend to cluster. It is important to note that for SEM analysis, the samples were dried and observed under vacuum, which probably have affected the structure and shape of the LNPs. This preparation process can introduce artifacts that would not typically be present in solution and should be considered when interpreting the results. Additionally, the contrast under vacuum conditions was too low to reliably distinguish the LNPs with sufficient detail. It provided a useful initial glimpse into the world of nanoparticles. Further complementary techniques will be needed for a more accurate and detailed characterization.</p>
          <H4 text="Corden LNP"/>
          <H5 text="Transfection"/>
          <p>Fluorescence microscopy with the Leica DMI6000 B microscope at 20x magnification was  by us on HEK293 cells transfected with LNPs containing pcDNA 3.1 eYFP DNA and mRNA. Minicircle DNA served as the positive control, while LNPs without cargo acted as the negative control. Cells were imaged at 24 h, 48 h, and 72 h post-transfection.</p>
          <div className="row align-items-center">
        <div className="col">
          <figure>
            <img src="https://static.igem.wiki/teams/5247/delivery/results/whatsapp-image-2024-09-24-at-12-57-59.jpeg"/>
            <figcaption>
              <b>Figure X. </b>
              Turbidity after components of the Corden LNP have been pipetted together indicates particle formation.            </figcaption>
          </figure>
        </div>
        <div className="col">
              <p>During the preparation of the LNPs, the solution became turbid and bluish, indicating successful nanoparticle formation (Figure X). This was further confirmed by cryo-EM analysis, which revealed the presence of well-formed LNPs. Despite the successful formation of LNPs, no detectable fluorescence was observed in the cells treated with LNPs containing pcDNA 3.1 eYFP DNA or mRNA at any of the measured time points, indicating that transfection did not occur under these conditions.</p>
            </div>
        </div>
        <p>Quantitatively, none of the LNP-treated samples showed significant fluorescence, indicating a failure in transfection. The lack of fluorescence in all experimental groups, except the positive control, suggests either insufficient uptake of the LNPs by the cells or a failure in expression of the YFP reporter. </p>
        <p>Fluorescence microscopy with the Leica DMI6000 B microscope at 20x magnification was  by performed us on HEK293 cells transfected with LNPs containing pcDNA 3.1 eYFP DNA and mRNA. Minicircle DNA served as the positive control, while LNPs without cargo acted as the negative control. Cells were imaged at 24 h, 48 h, and 72 h post-transfection.</p>
        <p>Quantitatively, after 72 h none of the LNP-treated samples showed significant fluorescence, indicating a failure in transfection (Figure 21). The lack of fluorescence in all experimental groups, except lipofectamine and Minicircle DNA as the positive control, suggests either insufficient uptake of the LNPs by the cells or a failure in expression of the YFP reporter, indicating that the Corden LNP may not suited as our delivery system. Also the deformed morphology and decreased growth are indicators for negative effects of the Cayman LNP on HEK293, probably reasoned in the employment of more cytotoxic mPEG-DSPE compared to DMG-PEG in the Cayman and SORT LNP.</p>
        <figure>
              <img src="https://static.igem.wiki/teams/5247/delivery/results/precyse/corden.png"/>
              <figcaption>
                <b>Figure 21. </b>
                Overlay of phase contrast and fluorescence microscopic images of transfected HEK293 cells at 20x magnification after 72 h post-transfection with different Corden LNP formulations recorded with Leica DMI6000 B.
              </figcaption>
        </figure>
        <H5 text="Cryo-EM"/>
        <p>Cryo-EM (cryogenic electron microscopy) as a form of transmission electron microscopy (TEM) was performed by us using a JEOL JEM-2200FS electron microscope (JEOL, Freising, Germany) operating at 200kV, equipped with a cold field emission electron gun. The sample preparation and imaging were carried out at cryogenic temperatures, which allowed for the visualization of LNPs in their native hydrated state.</p>
        <div className="row align-items-center">
          <div className="col">
            <figure>
              <img src="https://static.igem.wiki/teams/5247/delivery/results/corden-lnp.jpg"/>
              <figcaption>
                <b>Figure X. </b>
                Cryo-EM image of Corden LNPs.
              </figcaption>
            </figure>
          </div>
          <div className="col">
            <p>The images reveal the presence of spherical LNP structures with an approximate size of 100 nm (Figure X). The LNPs appear well-formed, with uniform morphology, indicating successful nanoparticle formation. In addition to individual particles, some larger, round structures were also observed, which could represent aggregated LNPs. These aggregations are a common phenomenon in LNP systems and could be attributed to interactions between particles under certain conditions.</p>
          </div>
        </div>
        <p>While Cryo-EM provides valuable insights into the morphology and size distribution of the LNPs, there are some limitations to this technique. The imaging process involves cryogenic freezing and exposure to high-energy electron beams, which can potentially induce minor structural artifacts. Furthermore, the thinness of the sample may limit contrast, making it difficult to fully distinguish between different LNP populations or their internal structures. Despite these limitations, Cryo-EM still offers a high-resolution view of the LNPs in their near-native state, providing essential information about their size and shape.</p>
        <H4 text="Sort LNP"/>
        <H5 text="Transfection"/>
          <p>Already at 48 h of 72 monitored hours post-transfection of HEK293 with the SORT LNP, clear and strong fluorescence was already observed when using LNPs combined with Minicircle DNA, as well as in the Lipofectamine and Minicircle DNA condition, confirming successful transfection and robust expression of the eYFP reporter (Figure 23). This early detection of fluorescence highlights the efficiency of SORT LNPs as delivery system. In contrast, no fluorescence was detected in any conditions involving Lipofectamine alone, Lipofectamine with RNA, or LNPs combined with DNA or RNA, further emphasizing the superior performance of the Minicircle DNA formulations and highlighting the need for improvement for our DNA choice and RNA synthesis.</p>
            <figure>
              <img src="https://static.igem.wiki/teams/5247/delivery/results/precyse/sort.png"/>
              <figcaption>
                <b>Figure 23. </b>
                Overlay of phase contrast and fluorescence microscopic images of transfected HEK293 cells at 20x magnification after 48 h post-transfection with different SORT LNP formulations recorded with Leica DMI6000 B.
              </figcaption>
        </figure>
        <H5 text="Flow cytometry"/>
          <div className="row align-items-center">
          <p>We performed flow cytometries analysis 72 h post-transfection to evaluate the transfection efficiency of the SORT LNP in HEK293. The relative percentage of fluorescent cells was determined by measuring the percentage of FITC-A+ cells, followed by normalization to the negative control and fold change calculation.</p>
            <div className="col">
              <figure>
              <img src="https://static.igem.wiki/teams/5247/delivery/results/sortlnp-facs.png" alt="SORTFACS" style={{maxHeight: "200pt"}}/> 
                <figcaption>
                 <b>Figure X. </b>
                 Percentage of fluorescent cells (FITC-A+) performed 72 h post-transfection of SORT LNP in HEK293. Mean +/- SEM for n=3. For statistics one-way ANOVA was performed. 
                </figcaption>
              </figure>
            </div>
            <div className="col">
              <p>The SORT LNP-transfected sample carrying Minicircle DNA exhibited a significant increase in fluorescence compared to the lipofectamine transfection of Minicircle DNA, with approximately 14 times more fluorescent cells compared to the lipofectamine-transfected sample (Figure a). This substantial difference indicates that the transfection efficiency with LNPs is markedly higher than with lipofectamine, demonstrating the superior performance of our LNP formulation in delivering nucleic acids to HEK cells.</p>
            </div>
          </div>
          <H5 text="Zeta Potential"/>
            <div className="row align-items-center">
              <div className="col">
                <p>We measured both the particle size distribution and the Zeta potential using the Nanotrack Wave II. We could assume that the particles exhibit a polarized Zeta potential, which is sufficient to provide electrostatic stabilization, thereby preventing aggregation and maintaining particle stability. For effective targeting of lung cells which have negatively charged surfaces, a negative polarity is desirable meaning the LNP is positively charged, so there can be electrostatic attraction to lung epithelial cells. We were able to show that our SORT LNP has these properties regardless of the load. Furthermore we could <a href="https://chem.libretexts.org/Bookshelves/Analytical_Chemistry/Physical_Methods_in_Chemistry_and_Nano_Science_(Barron)/02%3A_Physical_and_Thermal_Analysis/2.05%3A_Zeta_Potential_Analysis" title="StabZeta" >determine the stability via the Zeta potential</a>. In detail the mean of the Zeta potential lays at 16.2 mV for the SORT LNP with Minicircle DNA as cargo, indicating incipient stability, at 59.45 mV for the SORT LNP with pcDNA 3.1 eYFP as cargo, indicating good stability and at 88.22 mV for the SORT LNP without cargo indicating excellent stability (Figure z). The good stability of the SORT LNP with pcDNA 3.1 eYFP is crucial for our purposes, as it ensures effective delivery and performance. In contrast, the stability of the LNPs with Minicircle DNA can be considered secondary, as it primarily serves as a positive transfection control and is not central to our main objectives.</p>
              </div>
              <div className="col">
                <figure>
                  <img src="https://static.igem.wiki/teams/5247/delivery/results/sort-zeta.webp"/>
                  <figcaption>
                    <b>Figure X. </b>
                    Zeta potential of SORT LNP with different cargos measured with Nanotrack Wave II indicating varying degrees of stability but most important good stability for the SORT LNP loaded with pcDNA 3.1 eYFP (LNP DNA). Mean +/- SEM for n=5. For statistics one-way ANOVA was performed.                  </figcaption>
                </figure>
              </div>
            </div>
            <div className="row align-items-center">
          <div className="col">
            <figure>
              <img src="https://static.igem.wiki/teams/5247/delivery/results/screenshot-2024-10-01-204938.png"/>
              <figcaption>
                <b>Figure X. </b>
                Size distribution for the SORT LNP with different cargos weighted by scattering intensity measured with Nanotrack Wave II.
              </figcaption>
            </figure>
          </div>
          <div className="col">
            <p>The size distribution for all three samples shows a predominantly monomodal, yet broad, distribution with diameters ranging between 50 nm and 700 nm, with the peak of the distribution lying between 150 nm and 200 nm (Figure d). SORT LNPs without DNA exhibited larger radii, with a peak around 300 nm. The SORT LNP containing Minicircle DNA suggests the presence of larger aggregates with diameters exceeding 1 µm. The likely reason for this variable particle size distribution, despite loading with different types of DNA, could be attributed to the manufacturing method. Since the LNPs were not produced using an extruder but rather via dialysis, this is highly plausible.</p>
          </div>
          </div>
          <H5 text="Cryo-EM"/>
            <div className="row align-items-center">
                <div className="col">
                  <p>Cryo-EM analysis was also performed of SORT LNPs by us with the same JEOL JEM-2200FS microscope at 200kV, allowing visualization of LNPs in their native hydrated state. The images show spherical LNP structures around 100 nm, with some larger aggregates also present (data not shown). These aggregates likely result from interactions between particles due to the non-extrusion-based preparation method, which may explain the variability in particle size. Additionally, particles potentially representing different LNP populations or overlapped structures with low contrast were observed (Figure X). The low sample concentration likely contributed to the limited number of visible particles.</p>
                </div>
                <div className="col">
                  <figure>
                   <img src="https://static.igem.wiki/teams/5247/delivery/results/sortcryoem.png"/>
                   <figcaption>
                      <b>Figure X. </b>
                      Cryo-EM image of SORT LNPs. The different colored outlines indicate different size populations of LNPs.
                    </figcaption>
                  </figure>
                </div>
              </div>
              <p>Overall, while the Cryo-EM data confirm the presence and general morphology of LNPs that also fall within the diameter range specified by Wang et al. for SORT LNPs at smaller than 200 nm [link]. The variability in size and the presence of aggregates highlight potential areas for optimization, such as refining sample concentration and preparation methods to achieve more consistent particle formation.</p>
              <H5 text="DLS"/>
          <p>We used Dynamic Light Scattering (DLS) to assess the size distribution of our SORT LNPs by measuring the fluctuations in scattered light due to particle motion. The hydrodynamic diameter was calculated using the Stokes-Einstein equation, considering the diffusion coefficient, temperature, and viscosity of the medium.</p>
            <div className="row align-items-center">
              <div className="col">
                <figure>
                  <img src="https://static.igem.wiki/teams/5247/delivery/results/sort-dls.webp"/>
                  <figcaption>
                    <b>Figure X. </b>
                    Results for hydrodynamic radius determination by DLS Measurements for our SORT LNP, indicating a radius of approximately 100 nm.
                  </figcaption>
                </figure>
              </div>
              <div className="col">
                <p>The results showed a hydrodynamic diameter of SORT LNPs yielding an average radius of approximately 100 nm (Figure X). These findings are consistent with our previous applied size determination methods, such as Zeta potential and Cryo-EM, which also indicated similar particle dimensions in appropriate range for our research and medical applications.</p>
              </div>
            </div>
          <H5 text="MTT Assay"/>
            <div className="row align-items-center">
              <div className="col">
                <figure>
                 <img src="https://static.igem.wiki/teams/5247/fanzor/sort-mtt.webp"/>
                  <figcaption>
                  <b>Figure X. </b>
                  MTT Assay of LNPs from all iterations performed on HEK293 including Triton as negative control and untreated cells as positive control. Mean +/- SEM for n=6. For statistics one-way ANOVA was performed.                  </figcaption>
                </figure>
              </div>
              <div className="col">
                {/* <p>In order to evaluate the <a onClick={() => goToPageAndScroll ('Biosafety2', '/safety')}>biosafety</a> of our lung-specific LNPs, particularly concerning the choice of <a onClick={() => goToPagesAndOpenTab({collapseId: 'Col1', path: '/engineering', tabId: 'delivery' })}>PEG</a> - known to cause cytotoxicity issues - we performed MTT assays using HEK293 cells with various LNP formulations. The results demonstrated that the Cayman LNP achieved 74.90% viability and SORT LNP showed 75.01% viability, exhibiting lower cytotoxicity due to the inclusion of DMG-PEG, a less cytotoxic PEG variant compared to mPEG-2000-DSPE, which resulted in 66.69% viability in the Corden LNP (Figure t). These findings prove we made the best decision by choosing the SORT LNP as the least cytotoxic LNPs.</p> */}
                <p>In order to evaluate the <a onClick={() => goToPageAndScroll ('Biosafety2', '/safety')}>biosafety</a> of our lung-specific LNPs, particularly concerning the choice of PEG - known to cause cytotoxicity issues - we performed MTT assays using HEK293 cells with various LNP formulations. The results demonstrated that the Cayman LNP achieved 74.90% viability and SORT LNP showed 75.01% viability, exhibiting lower cytotoxicity due to the inclusion of DMG-PEG, a less cytotoxic PEG variant compared to mPEG-2000-DSPE, which resulted in 66.69% viability in the Corden LNP (Figure t). These findings prove we made the best decision by choosing the SORT LNP as the least cytotoxic LNPs.</p>
              </div>
            </div>
      </Subesction >
      
            
            <H4 text="SORT LNP Chitosan-RNA Complex"/>
            <p>We successfully transfected a well-established lung epithelial cell line CFBE41o- with our chitosan-RNA complexes using our synthesized pcDNA 3.1 eYFP mRNA, which were subsequently incubated with SORT LNPs for packaging. The goal was to encapsulate the chitosan-RNA complexes within the LNPs to enhance mRNA delivery to cells. After formulation, the LNP Chitosan-RNA complexes were transfected into CFBE41o- cells, to assess the efficiency of mRNA delivery and expression.</p>
          <p>We tested two different chitosan and mRNA concentrations (always used both in the same concentrations), 50 ng/µl and 500 ng/µl, in combination with our LNP to assess their impact on transfection efficiency. Interestingly, both concentrations resulted in similarly high levels of transfection, as evidenced by the fluorescence microscopy images, further validation is necessary to confirm these results.</p>
          <p>Fluorescence microscopy was performed 24 hours post-transfection to evaluate the expression of the YFP reporter gene encoded by the pcDNA 3.1 eYFP mRNA. This reporter gene serves as an indicator of successful transfection and translation of the mRNA into protein. The results of the fluorescence microscopy were highly positive and aligned with our expectations, indicating efficient delivery, uptake, and expression of the mRNA in the CFBE41o- cells.</p>
          <H4 text="Flow cytometry"/>
          <p>We tested two different chitosan and mRNA concentrations (always used both in the same concentrations), 50 ng/µl and 500 ng/µl, in combination with our LNP to assess their impact on transfection efficiency. Interestingly, both concentrations resulted in similarly high levels of transfection, as evidenced by the fluorescence microscopy images, further validation is necessary to confirm these results.</p>
          <div className="row align-items-center">
              <div className="col">
                <figure>
                  <img src="https://static.igem.wiki/teams/5247/delivery/results/precyse/lnp-chito-rna500-t24.webp"/>
                  <figcaption>
                    <b>Figure 30. </b>
                    Overlay of phase contrast and fluorescence microscopic images of with SORT + chitosan 500 transfected CFBE41o- cells at 20x magnification after 48 h post-transfection recorded with Leica DMI6000 B.
                  </figcaption>
                </figure>
              </div>
              <div className="col">
              <p>The sample containing 500 ng/µl of chitosan and pcDNA 3.1 eYFP mRNA, encapsulated within SORT LNPs, exhibited fluorescence 24 hours post-transfection (Figure 30). This result indicates that the RNA was successfully delivered into the CFBE41o- cells, where it was transcribed and translated into the YFP protein. The presence of YFP fluorescence confirms not only successful transfection but also robust expression of the reporter gene.</p>
              </div>
            </div>
            <div className="row align-items-center">
            <div className="col">
              <p>In the sample containing 50 ng/µl of chitosan and pcDNA 3.1 eYFP mRNA was used, which is tenfold lower than the chitosan and mRNA concentration used in the chitosan500 sample (see above). Despite the lower mRNA concentration, fluorescence was still observed (Figure 31) indicating that the mRNA was efficiently delivered and expressed in the CFBE41o- cells. This result suggests that even at lower mRNA doses, the system can achieve successful transfection and gene expression. We are planning to perform a more detailed comparison of fluorescence intensity between the chitosanRNA500 and chitosanRNA50 samples and even lower concentrations to assess the relationship between mRNA dose and expression level.</p>
              </div>
              <div className="col">
                <figure>
                  <img src="https://static.igem.wiki/teams/5247/delivery/results/precyse/lnpchito-rna50-t24.webp"/>
                  <figcaption>
                    <b>Figure 31. </b>
                    Overlay of phase contrast and fluorescence microscopic images of with SORT + chitosan 50 transfected CFBE41o- cells at 20x magnification after 48 h post-transfection recorded with Leica DMI6000 B.
                  </figcaption>
                </figure>
              </div>
            </div>
            <p>The samples containing only chitosan (Figure 32) and only SORT LNP (Figure 33) without any mRNA, did not exhibit any detectable fluorescence. This result is consistent with expectations, as chitosan alone and SORT LNP alone are not fluorescent. These samples served as important negative controls to confirm that the chitosan itself and the SORT LNP itself don't interfere with the fluorescence signal.</p>
            <div className="row align-items-center">
              <div className="col">
                <figure>
                  <img src="https://static.igem.wiki/teams/5247/delivery/results/precyse/chito-t24-1.jpeg"/>
                  <figcaption>
                    <b>Figure 32. </b>
                    Overlay of phase contrast and fluorescence microscopic images of with SORT transfected CFBE41o- cells at 20x magnification after 48 h post-transfection recorded with Leica DMI6000 B.
                  </figcaption>
                </figure>
              </div>
              <div className="col">
                <figure>
                  <img src="https://static.igem.wiki/teams/5247/delivery/results/precyse/lnp-leer-t24.webp"/>
                  <figcaption>
                    <b>Figure 33. </b>
                    Overlay of phase contrast and fluorescence microscopic images of with chitosan transfected CFBE41o- cells at 20x magnification after 48 h post-transfection recorded with Leica DMI6000 B.
                  </figcaption>
                </figure>
              </div>
            </div>  
            <div className="row align-items-center">
              <div className="col">
                <figure>
                  <img src="https://static.igem.wiki/teams/5247/delivery/results/precyse/ntc-t24.webp"/>
                  <figcaption>
                    <b>Figure 34. </b>
                    Overlay of phase contrast and fluorescence microscopic images of untransfected CFBE41o- cells at 20x magnification after 48 h post-transfection recorded with Leica DMI6000 B.
                  </figcaption>
                </figure>
              </div>
              <div className="col">
              <p>The untreated control, which did not receive any chitosan, RNA, or LNPs, did not show any fluorescence (Figure 34). This negative control confirms that the cells themselves do not express YFP under normal conditions, and that any observed fluorescence in the experimental groups is directly attributable to the transfection and expression of the delivered RNA.</p>
              </div>
            </div>
      <p>The results demonstrate that chitosan-RNA complexes, when packaged with SORT LNPs, can efficiently deliver mRNA into CFBE41o- cells and facilitate the expression of a YFP reporter gene. Furthermore, the absence of fluorescence in the control samples validates the specificity of the system, ensuring that the fluorescence signal is solely due to the delivered mRNA and not from other components of the system. Additional testing, such as flow cytometry analysis, is planned to provide a more quantitative assessment of transfection efficiency. This would allow us to accurately determine whether there are subtle differences between the two concentrations that were not detectable by microscopy alone.</p>

      <Subesction  title="PreCyse" id="Results4">
          <H4 text="Goals"/>
          <p>text</p> 
          <H4 text="Workflow"/>
          <p>text</p> 
          <H4 text="Conclusion"/>
          <p>text</p> 
      </Subesction >
      <Subesction  title="Patch Clamp" id="Results5">
          <p>To validate our gene editing approach by prime editing of CFTR F508del delivered to lung cells via SORT LNPs, we planned to use <a onClick={() => goToPageAndScroll ('Patch Clamp', '/materials-methods')}>Patch Clamp</a> as a downstream method. Our goal was to detect the restored conductance of the repaired CFTR by this electrophysiological method. This was made possible through the assistance of the <a onClick={() => goToPagesAndOpenTab('patchclamp', '/human-practices')}>Cellular Neurophysiology research group</a> at our university.</p>
          <H4 text="Initial Measurements"/>
            <div className='row align-items-center'>
              <div className='col'>
                <figure> 
                  <img src="https://static.igem.wiki/teams/5247/photos/results/patchclamp/pc1.webp" alt="PC1" style={{maxHeight: "300pt"}}/> 
                  <figcaption> 
                  <b>Figure 1. </b> 
                  Current density of HEK293, HEK293T CFTR WT and HEK293T CFTR F508del showing significant differences of both HEK293T cell lines compared to HEK293 but no significant differences between them. For statistics one-way ANOVA was performed.
                  </figcaption> 
                </figure> 
              </div>
              <div className='col'>
                <p>In our first set of experiments, we measured current density in <a onClick={() => goToPageAndScroll ('Cell Culture', '/materials-methods')}>HEK293T CFTR wild-type (WT) and HEK293T F508del</a> cell lines, comparing them with regular HEK293. The results demonstrated significant differences in chloride ion conductance, with the CFTR-expressing cell lines showing enhanced conductivity compared to HEK293 (Figure 1). However, a drawback was that we did not observe any significant differences between the HEK293T CFTR WT and F508del cell line. This was unexpected, as the F508del mutation typically leads to a knockdown of the CFTR protein, impairing chloride ion transport through the CFTR channel.</p>
              </div>
            </div>
            <H4 text="Further Validation and Challenges"/>
            <div className='row align-items-center'>
            <div className='col'>
              <p>In light of these results, we improved our experimental setup and performed additional validation experiments. Unfortunately, the repeated measurements yielded similar outcomes, confirming the absence of a significant difference between the two CFTR-expressing cell lines (Figure 2). This finding led us to consult with the research group at <a onClick={() => goToPagesAndOpenTab('mattijsvisit', '/human-practices')}>KU Leuven</a>, who established these cells lines. Although they had not conducted similar Patch Camp measurements, they suggested an alternative approach using Ussing Chamber measurements. This technique, unlike Patch Camp, does not rely on single-cell measurements but rather examines the ion currents across the entire cell monolayer, which may provide a more comprehensive view of CFTR functionality.</p>
              </div>
              <div className='col'>
                <figure> 
                  <img src="https://static.igem.wiki/teams/5247/photos/results/patchclamp/pc2.webp" alt="PC1" style={{maxHeight: "300pt"}}/> 
                  <figcaption> 
                  <b>Figure 2. </b> 
                  Repeated validation of current density measurements in HEK293T CFTR WT and HEK293T CFTR-F508del, showing consistent results with the initial experiment. For statistics one-way ANOYA was performed.
                  </figcaption> 
                </figure> 
              </div>
            </div>
            <H4 text="Next Steps"/>
            <p>Following the recommendations from KU Leuven, we have also taken steps to expand our experimental approach. To further investigate the CFTR functionality, we have ordered <a onClick={() => goToPageAndScroll ('Cell Culture', '/materials-methods')}>CFBE41o-</a> as a new cell line from <a onClick={() => goToPagesAndOpenTab('ignatova', '/human-practices')}>Prof. Dr. Ignatova</a> in Hamburg. Our goal is to use these patient-derived cells to measure ion currents and further elucidate the impact of the mutation on chloride conductance. This will not only provide a more clinically relevant model but may also yield more distinct results in comparison to the previous experiments with the engineered HEK293T cells.</p>
      </Subesction >
      </Section>
      <Section title="Supplementary Material" id="Supplementary Material">    
      <p>Supplementary Material for Patch Clamp</p>
      <p><DownloadLink url="https://static.igem.wiki/teams/5247/pdfs/raw-data-patch-clamp.pdf" fileName="raw-data-patch-clamp.pdf" /></p>
      <p>Supplementary Material for Delivery</p>
      <DownloadLink url="https://static.igem.wiki/teams/5247/pdfs/raw-data-patch-clamp.pdf" fileName="raw-data-patch-clamp.pdf" />
      </Section>
    </>
  );
}




